@@ -4,8 +4,8 @@ http://techspot.zzzeek.org/2012/07/07/the-absolutely-simplest-consistent-hashing
 """
 
 from collections import Counter
+from itertools import cycle
 from math import sqrt
-from random import randint
 
 from uhashring import HashRing
 
@@ -25,9 +25,10 @@ def test_distribution():
     for i in range(1, numnodes + 1):
         ring["node{}".format(i)] = {"instance": "node_value{}".format(i)}
 
+    deterministic_input = cycle(range(1, numvalues))
     distribution = Counter()
     for i in range(numhits):
-        key = str(randint(1, numvalues))
+        key = str(next(deterministic_input))
         node = ring[key]
         distribution[node] += 1
 
@@ -43,6 +44,4 @@ def test_distribution():
 
     # just to test getting keys, see that we got the values
     # back and not keys or indexes or whatever.
-    assert set(distribution.keys()) == set(
-        "node_value{}".format(i) for i in range(1, 1 + numnodes)
-    )
+    assert set(distribution.keys()) == set("node_value{}".format(i) for i in range(1, 1 + numnodes))
