@@ -17,9 +17,7 @@ class MetaRing:
 
         if hash_fn and not hasattr(hash_fn, "__call__"):
             raise TypeError("hash_fn should be a callable function")
-        self._hash_fn = hash_fn or (
-            lambda key: int(md5(str(key).encode("utf-8")).hexdigest(), 16)
-        )
+        self._hash_fn = hash_fn or (lambda key: int(md5(str(key).encode("utf-8")).hexdigest(), 16))
 
     def hashi(self, key):
         """Returns an integer derived from the md5 hash of the given key."""
@@ -42,9 +40,7 @@ class MetaRing:
             node_conf = self._nodes.pop(node_name)
         except Exception:
             raise KeyError(
-                "node '{}' not found, available nodes: {}".format(
-                    node_name, self._nodes.keys()
-                )
+                "node '{}' not found, available nodes: {}".format(node_name, self._nodes.keys())
             )
         else:
             self._distribution.pop(node_name)
